Index: src/core/SkBlitter.h |
diff --git a/src/core/SkBlitter.h b/src/core/SkBlitter.h |
index baa9ccc39f878a171197808aa65c904c997e5170..5740a5eaedf2f3df22819e2a92c87eae0dec1d12 100644 |
--- a/src/core/SkBlitter.h |
+++ b/src/core/SkBlitter.h |
@@ -50,7 +50,7 @@ public: |
virtual void blitMask(const SkMask&, const SkIRect& clip); |
/** If the blitter just sets a single value for each pixel, return the |
- bitmap it draws into, and assign value. If not, return NULL and ignore |
+ bitmap it draws into, and assign value. If not, return nullptr and ignore |
the value parameter. |
*/ |
virtual const SkPixmap* justAnOpaqueColor(uint32_t* value); |
@@ -109,7 +109,7 @@ public: |
* This function allocates memory for the blitter that the blitter then owns. |
* The memory can be used by the calling function at will, but it will be |
* released when the blitter's destructor is called. This function returns |
* NULL if no persistent memory is needed by the blitter. |
*/ |
virtual void* allocBlitMemory(size_t sz) { |
return fBlitMemory.reset(sz, SkAutoMalloc::kReuse_OnShrink); |
@@ -229,7 +229,7 @@ private: |
class SkBlitterClipper { |
public: |
SkBlitter* apply(SkBlitter* blitter, const SkRegion* clip, |
- const SkIRect* bounds = NULL); |
+ const SkIRect* bounds = nullptr); |
private: |
SkNullBlitter fNullBlitter; |
@@ -109,7 +109,7 @@ public: |
* The memory can be used by the calling function at will, but it will be |
* released when the blitter's destructor is called. This function returns |
- * NULL if no persistent memory is needed by the blitter. |
+ * nullptr if no persistent memory is needed by the blitter. |
*/ |
virtual void* allocBlitMemory(size_t sz) { |